<?php
$lang['expired_searchable'] = 'Vypr&scaron;an&eacute; čl&aacute;nky sa m&ocirc;žu objaviť vo v&yacute;sledkoch vyhľad&aacute;vania';
$lang['helpshowall'] = 'Zobraziť v&scaron;etky čl&aacute;nky, bez ohľadu na d&aacute;tum konca';
$lang['error_invaliddates'] = 'D&aacute;tumy boli vložen&eacute; nespr&aacute;vne';
$lang['notify_n_draft_items_sub'] = '%d novinka';
$lang['notify_n_draft_items'] = 'M&aacute;te %s ktor&eacute; nie je/s&uacute; publikovan&eacute;';
$lang['unlimited'] = 'Bez obmedzenia';
$lang['none'] = 'Žiadne';
$lang['anonymous'] = 'Anonym';
$lang['unknown'] = 'Nezn&aacute;my';
$lang['fesubmit_redirect'] = 'PageID alebo alias  pre presmerovanie po pridan&iacute; novinky odoslanej cez front-end formul&aacute;r';
$lang['allow_summary_wysiwyg'] = 'Povoliť použ&iacute;vanie WYSIWYG editora pre pole s&uacute;hrnu';
$lang['title_browsecat_template'] = 'Editor pre &scaron;abl&oacute;nu zoznamu kateg&oacute;rii';
$lang['title_browsecat_sysdefault'] = 'Prednastaven&aacute; &scaron;abl&oacute;na pre zoznam kateg&oacute;rii';
$lang['browsecattemplate'] = '&Scaron;abl&oacute;ny pre zoznam kateg&oacute;rii';
$lang['error_filesize'] = 'Nahr&aacute;van&yacute; s&uacute;bor prekročil povolen&uacute; maxim&aacute;lnu veľkosť s&uacute;bora';
$lang['post_date_desc'] = 'D&aacute;tum publikovania - zostupne';
$lang['post_date_asc'] = 'D&aacute;tum publikovania - vzostupne';
$lang['expiry_date_desc'] = 'D&aacute;tum expir&aacute;cie - zostupne';
$lang['expiry_date_asc'] = 'D&aacute;tum expir&aacute;cie - vzostupne';
$lang['title_desc'] = 'Nadpis - zostupne';
$lang['title_asc'] = 'Nadpis - vzostupne';
$lang['status_desc'] = 'Stav vzostupne';
$lang['status_asc'] = 'Stav zostupne';
$lang['fesubmit_status'] = 'Stav novinky po odoslan&iacute; cez front-end';
$lang['error_invalidfiletype'] = 'Nie je možn&eacute; nahrať tento typ s&uacute;boru';
$lang['error_upload'] = 'Probl&eacute;m pri nahr&aacute;van&iacute; s&uacute;boru';
$lang['error_movefile'] = 'Nie je možn&eacute; vytvoriť s&uacute;bor: %s';
$lang['error_mkdir'] = 'Nie je možn&eacute; vytvoriť adres&aacute;r: %s';
$lang['expiry_interval'] = 'Počet dn&iacute;  (prednastaven&yacute;ch) pre expir&aacute;ciu novinky (v pr&iacute;pade že expir&aacute;ciu pri novinke vyberiete)';
$lang['removed'] = 'Odstr&aacute;nen&yacute;';
$lang['msg_contenttype_removed'] = 'Podpora pre typ obsahu str&aacute;nky pre novinky bola zru&scaron;en&aacute;.  Pros&iacute;m vložte tag {news} s pr&iacute;slu&scaron;n&yacute;mi parametrami do va&scaron;ej str&aacute;nky, pr&iacute;padne &scaron;abl&oacute;ny.';
$lang['delete_selected'] = 'Odstr&aacute;niť vybran&eacute; novinky';
$lang['areyousure_deletemultiple'] = 'Ste si ist&yacute;, že chcete odstr&aacute;niť v&scaron;etky vybran&eacute; novinky?\nNie je možn&eacute; ich nesk&ocirc;r obnoviť!';
$lang['error_templatenamexists'] = '&Scaron;abl&oacute;na s t&yacute;mto n&aacute;zvom už existuje';
$lang['error_noarticlesselected'] = 'Neboli vybran&eacute; žiadne novinky';
$lang['reassign_category'] = 'Zmeniť kateg&oacute;riu na';
$lang['select'] = 'Vybrať';
$lang['approve'] = 'Set Status to &#039;Published&#039;';
$lang['revert'] = 'Set Status to &#039;Draft&#039;';
$lang['hide_summary_field'] = 'Skryť pole pre s&uacute;hrn pri prid&aacute;van&iacute; a edit&aacute;cii noviniek';
$lang['textbox'] = 'Textov&eacute; pole';
$lang['checkbox'] = 'Za&scaron;krt&aacute;vacie pole';
$lang['textarea'] = 'Textov&aacute; oblasť';
$lang['file'] = 'S&uacute;bor';
$lang['auto_create_thumbnails'] = 'Automaticky vytvoriť n&aacute;hľady pre s&uacute;bory s t&yacute;mito koncovkami';
$lang['allowed_upload_types'] = 'Povoliť nahr&aacute;vanie s&uacute;borov s t&yacute;mito koncovkami';
$lang['fielddefupdated'] = 'Vlastn&eacute; pole bolo aktualizovan&eacute;';
$lang['editfielddef'] = '&Uacute;prava vlastn&eacute;ho pola';
$lang['up'] = 'Hore';
$lang['down'] = 'Dole';
$lang['fielddefdeleted'] = 'Vlastn&eacute; pole odstr&aacute;nen&eacute;';
$lang['nameexists'] = 'Vlastn&eacute; pole s t&yacute;mto n&aacute;zvom už existuje';
$lang['notanumber'] = 'Maxim&aacute;lna dĺžka poľa mus&iacute; byť č&iacute;slo';
$lang['fielddef'] = 'Vlastn&eacute; pole';
$lang['fielddefadded'] = 'Vlastn&eacute; pole bolo &uacute;spe&scaron;ne pridan&eacute;';
$lang['public'] = 'Verejn&eacute;';
$lang['type'] = 'Typ';
$lang['info_maxlength'] = 'Maxim&aacute;lna dĺžka poľa sa použ&iacute;va iba pre textov&eacute; polia';
$lang['maxlength'] = 'Maxim&aacute;lna dĺžka';
$lang['addfielddef'] = 'Pridať vlastn&eacute; pole';
$lang['customfields'] = 'Vlastn&eacute; polia';
$lang['deprecated'] = 'nepodporovan&eacute;';
$lang['subject_newnews'] = 'Bola pridan&aacute; novinka';
$lang['email_subject'] = 'Predmet odch&aacute;dzaj&uacute;cej spr&aacute;vy';
$lang['email_template'] = 'Obsah e-mailovej spr&aacute;vy';
$lang['formsubmit_emailaddress'] = 'E-mailov&aacute; adresa pre prij&iacute;manie notifik&aacute;cie odoslan&yacute; noviniek cez front-end';
$lang['extra'] = 'Extra pole';
$lang['uploadscategory'] = 'Nahr&aacute; kateg&oacute;riu';
$lang['title_available_templates'] = 'Dostupn&eacute; &scaron;abl&oacute;ny';
$lang['resettodefault'] = 'Obnoviť v&yacute;chodzie nastavenia';
$lang['title_form_template'] = 'Editor pre &scaron;asbl&oacute;nu pre formul&aacute;r';
$lang['title_detail_template'] = 'Editor &scaron;abl&oacute;ny podrobnosti';
$lang['title_summary_template'] = 'Editor &scaron;abl&oacute;ny s&uacute;hrnu';
$lang['prompt_templatename'] = 'N&aacute;zov &scaron;abl&oacute;ny';
$lang['prompt_template'] = 'Zdroj &scaron;abl&oacute;ny';
$lang['title_form_sysdefault'] = 'Prednastaven&aacute; &scaron;abl&oacute;na pre formul&aacute;r';
$lang['title_summary_sysdefault'] = 'V&yacute;chodzia &scaron;abl&oacute;na s&uacute;hrnu ';
$lang['title_detail_sysdefault'] = 'V&yacute;chodzia &scaron;abl&oacute;na podrobnosti';
$lang['info_sysdefault2'] = '<strong>Note:</strong> This tab contains text areas to allow you to edit a set of templates that are displayed when you create a &#039;new&#039; summary, detail, or form template.  Changing content in this tab, and clicking &#039;submit&#039; will <strong>not effect any current displays</strong>.';
$lang['info_sysdefault'] = '<em>(v&yacute;chodzia &scaron;abl&oacute;na pre nov&uacute; &scaron;abl&oacute;nu)</em>';
$lang['template'] = '&Scaron;abl&oacute;na';
$lang['prompt_name'] = 'Meno';
$lang['prompt_default'] = 'V&yacute;chodzie';
$lang['prompt_newtemplate'] = 'Vytvoriť nov&uacute; &scaron;abl&oacute;nu';
$lang['help_pagelimit'] = 'Najv&auml;č&scaron;&iacute; počet položiek pre zobrazenie na str&aacute;nke. Ak tento &uacute;daj nie je zadan&yacute;, bud&uacute; zobrazen&eacute; v&scaron;etky vyhovuj&uacute;ce položky. Ak je zadan&yacute; a je dostupn&yacute;ch viacej položiek, ako určuje parameter, bude vytvoren&yacute; text a linky pre umožnenie prech&aacute;dzania v&yacute;sledkami.';
$lang['prompt_page'] = 'Str&aacute;nka';
$lang['firstpage'] = '<<';
$lang['prevpage'] = '<';
$lang['nextpage'] = '>';
$lang['lastpage'] = '>>';
$lang['prompt_of'] = 'z';
$lang['prompt_pagelimit'] = 'Limit str&aacute;nky';
$lang['prompt_sorting'] = 'Zoradiť podľa';
$lang['title_filter'] = 'Filtre';
$lang['published'] = 'Publikovan&eacute;';
$lang['draft'] = 'N&aacute;vrh';
$lang['expired'] = 'Star&eacute;';
$lang['author'] = 'Autor';
$lang['sysdefaults'] = 'Obnoviť v&yacute;chodzie nastavenie';
$lang['restoretodefaultsmsg'] = 'T&aacute;to oper&aacute;cia obnov&iacute; v&yacute;chodz&iacute; obsah &scaron;abl&oacute;n.  Ste si ist&yacute;, že chcete pokračovať?';
$lang['addarticle'] = 'Vložiť pr&iacute;spevok';
$lang['articleadded'] = 'Pr&iacute;spevok bol &uacute;spe&scaron;ne pridan&yacute;.';
$lang['articleupdated'] = 'Pr&iacute;spevok bol &uacute;spe&scaron;ne upraven&yacute;.';
$lang['articledeleted'] = 'Pr&iacute;spevok bol &uacute;spe&scaron;ne zmazan&yacute;.';
$lang['addcategory'] = 'Vložiť kateg&oacute;riu';
$lang['categoryadded'] = 'Kateg&oacute;ria bola &uacute;spe&scaron;ne pridan&aacute;.';
$lang['categoryupdated'] = 'Kateg&oacute;ria bola &uacute;spe&scaron;ne upraven&aacute;.';
$lang['categorydeleted'] = 'Kateg&oacute;ria bola &uacute;spe&scaron;ne zmazan&aacute;.';
$lang['addnewsitem'] = 'Vložiť novinku';
$lang['allcategories'] = 'V&scaron;etky kateg&oacute;rie';
$lang['allentries'] = 'V&scaron;etky položky';
$lang['areyousure'] = 'Skutočne chcete vymazať?';
$lang['articles'] = 'Novinky';
$lang['cancel'] = 'Zru&scaron;iť';
$lang['category'] = 'Kateg&oacute;ria';
$lang['categories'] = 'Kateg&oacute;rie';
$lang['default_category'] = 'V&yacute;chodzia kateg&oacute;ria';
$lang['content'] = 'Obsah';
$lang['dateformat'] = '%s nie je v spr&aacute;vnom yyyy-mm-dd hh:mm:ss form&aacute;te';
$lang['delete'] = 'Zmazať';
$lang['description'] = 'Vložiť, upraviť alebo zmazať novinky';
$lang['formtemplate'] = '&Scaron;abl&oacute;na pre formul&aacute;r';
$lang['detailtemplate'] = '&Scaron;abl&oacute;na podrobnost&iacute;';
$lang['default_templates'] = 'Prednastaven&eacute; &scaron;abl&oacute;ny';
$lang['detailtemplateupdated'] = 'Upraven&aacute; &scaron;abl&oacute;na podrobnost&iacute; bola &uacute;spe&scaron;ne uložen&aacute; do datab&aacute;zy.';
$lang['displaytemplate'] = 'Zobraziť &scaron;ablonu';
$lang['edit'] = 'Upraviť';
$lang['enddate'] = 'Konč&iacute;';
$lang['endrequiresstart'] = 'Vloženie d&aacute;tumu konca potrebuje tiež d&aacute;tum začiatku';
$lang['entries'] = '%s položiek';
$lang['status'] = 'Stav';
$lang['expiry'] = 'Vypr&scaron;&iacute;';
$lang['filter'] = 'Filtre';
$lang['more'] = 'Viac';
$lang['category_label'] = 'Kateg&oacute;ria:';
$lang['author_label'] = 'Publikovan&eacute;:';
$lang['moretext'] = 'Viac textu';
$lang['name'] = 'Meno';
$lang['news'] = 'Novinky';
$lang['news_return'] = 'N&aacute;vrat';
$lang['newcategory'] = 'Nov&aacute; kateg&oacute;rie';
$lang['needpermission'] = 'Potrebujete &#039;%s&#039; opr&aacute;vnenia pre uskutočnenie tejto funkcie.';
$lang['nocategorygiven'] = 'Nebola zadan&aacute; kateg&oacute;ria';
$lang['startdatetoolate'] = 'D&aacute;tum začiatku je v&auml;č&scaron;&iacute; ako d&aacute;tum konca';
$lang['nocontentgiven'] = 'Nebol zadan&yacute; obsah';
$lang['noitemsfound'] = 'Neboli n&aacute;jdene <strong>žiadne</strong> položky v kateg&oacute;rii: %s';
$lang['nopostdategiven'] = 'Nebol zadan&yacute; d&aacute;tum publikovania';
$lang['note'] = '<em>Pozn&aacute;mka:</em> D&aacute;tumy musia byť v &#039;yyyy-mm-dd hh:mm:ss&#039; form&aacute;te.';
$lang['notitlegiven'] = 'Nebol zadan&yacute; nadpis';
$lang['nonamegiven'] = 'Nebolo zadan&eacute; žiadne meno';
$lang['numbertodisplay'] = 'Zobraziť počet (pr&aacute;zdne pre v&scaron;etky z&aacute;znamy)';
$lang['print'] = 'Tlačiť';
$lang['postdate'] = 'D&aacute;tum publikovania';
$lang['postinstall'] = 'Uistite sa, že použ&iacute;vatelia ktor&iacute; bud&uacute; spravovať novinky, maj&uacute; nastaven&eacute; opr&aacute;vnenie &quot;Modify News&quot;.';
$lang['selectcategory'] = 'Vybrať kateg&oacute;riu';
$lang['showchildcategories'] = 'Zobraziť podriaden&eacute; kateg&oacute;rie';
$lang['sortascending'] = 'Triediť vzostupne';
$lang['startdate'] = 'Zač&iacute;na';
$lang['startoffset'] = 'Začiatok zobrazovania od N-tej položky';
$lang['startrequiresend'] = 'Vloženie d&aacute;tumu začiatku potrebuje tiež d&aacute;tum ukončenia';
$lang['submit'] = 'Odoslať';
$lang['summary'] = 'S&uacute;hrn';
$lang['summarytemplate'] = '&Scaron;abl&oacute;na s&uacute;hrnu';
$lang['summarytemplateupdated'] = 'S&uacute;hrnn&aacute; &scaron;abl&oacute;na pre novinky bola &uacute;spe&scaron;ne upraven&aacute;.';
$lang['title'] = 'Nadpis';
$lang['options'] = 'Voľby';
$lang['optionsupdated'] = 'Voľby boli &uacute;spe&scaron;ne upraven&eacute;.';
$lang['useexpiration'] = 'Použ&iacute;ť d&aacute;tum konca';
$lang['eventdesc-NewsArticleAdded'] = 'Poslať po pridan&iacute; novinky';
$lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
<li>\&quot;category_id\&quot; - Id of the category for this article</li>
<li>\&quot;title\&quot; - Title of the article</li>
<li>\&quot;content\&quot; - Content of the article</li>
<li>\&quot;summary\&quot; - Summary of the article</li>
<li>\&quot;status\&quot; - Status of the article (&quot;draft&quot; or &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Date the article should start being displayed</li>
<li>\&quot;end_time\&quot; - Date the article should stop being displayed</li>
<li>\&quot;useexp\&quot; - Whether the expiration date should be ignored or not</li>
</ul>
';
$lang['eventdesc-NewsArticleEdited'] = 'Poslať po upraven&iacute; novinky';
$lang['eventhelp-NewsArticleEdited'] = '<p>Sent when an article is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
<li>\&quot;category_id\&quot; - Id of the category for this article</li>
<li>\&quot;title\&quot; - Title of the article</li>
<li>\&quot;content\&quot; - Content of the article</li>
<li>\&quot;summary\&quot; - Summary of the article</li>
<li>\&quot;status\&quot; - Status of the article (&quot;draft&quot; or &quot;publish&quot;)</li>
<li>\&quot;start_time\&quot; - Date the article should start being displayed</li>
<li>\&quot;end_time\&quot; - Date the article should stop being displayed</li>
<li>\&quot;useexp\&quot; - Whether the expiration date should be ignored or not</li>
</ul>
';
$lang['eventdesc-NewsArticleDeleted'] = 'Poslať po odstr&aacute;nen&iacute; novinky';
$lang['eventhelp-NewsArticleDeleted'] = '<p>Sent when an article is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;news_id\&quot; - Id of the news article</li>
</ul>
';
$lang['eventdesc-NewsCategoryAdded'] = 'Poslať po pridan&iacute; kateg&oacute;rie';
$lang['eventhelp-NewsCategoryAdded'] = '<p>Sent when a category is added.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the news category</li>
<li>\&quot;name\&quot; - Name of the news category</li>
</ul>
';
$lang['eventdesc-NewsCategoryEdited'] = 'Poslať po upraven&iacute; kateg&oacute;rie';
$lang['eventhelp-NewsCategoryEdited'] = '<p>Sent when a category is edited.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the news category</li>
<li>\&quot;name\&quot; - Name of the news category</li>
<li>\&quot;origname\&quot; - The original name of the news category</li>
</ul>
';
$lang['eventdesc-NewsCategoryDeleted'] = 'Poslať po odstr&aacute;nen&iacute; kateg&oacute;rie';
$lang['eventhelp-NewsCategoryDeleted'] = '<p>Sent when a category is deleted.</p>
<h4>Parameters</h4>
<ul>
<li>\&quot;category_id\&quot; - Id of the deleted category </li>
<li>\&quot;name\&quot; - Name of the deleted category</li>
</ul>
';
$lang['help_articleid'] = 'Tento parameter je použiteľn&yacute; iba pri použit&iacute; detailu novinky a definuje id konkr&eacute;tnej novnky. Hodnota -1 nastavuje detail najnov&scaron;ej publikovanej, neexpirovanej novinky.';
$lang['helpnumber'] = 'Maxim&aacute;lny počet položiek k zobrazeniu - ponechan&eacute; pr&aacute;zdne zobraz&iacute; v&scaron;etky položky.';
$lang['helpstart'] = 'Začiatok zobrazovania od N-tej položky -- ponechan&eacute; pr&aacute;zdne začne zobrazovať od prvej položky';
$lang['helpcategory'] = 'Zobraziť iba položky t&eacute;jto kateg&oacute;rie a &iacute;ch podpoložiek. Ponechan&eacute; pr&aacute;zdne zobraz&iacute; v&scaron;etky kateg&oacute;rie.';
$lang['helpmoretext'] = 'Text pre zobrazenie na konci novinky ak presahuje dĺžku s&uacute;hrnu. Predvolen&yacute; je &quot;more...&quot;';
$lang['helpsummarytemplate'] = 'Použ&iacute;vať oddelen&uacute; &scaron;abl&oacute;nu pre s&uacute;hrn.  T&aacute;to &scaron;abl&oacute;na m&aacute; byť v  modules/News/templates.';
$lang['helpformtemplate'] = 'Použitie &scaron;abl&oacute;ny z datab&aacute;zy pre zobrazenie  formul&aacute;ra pre odoslanie čl&aacute;nku. T&aacute;to &scaron;abl&oacute;na mus&iacute; byť vytvoren&aacute; a mus&iacute; byť zobrazen&aacute; v z&aacute;ložke &Scaron;abl&oacute;na pre formul&aacute;r. V pr&iacute;pade, že tento parameter zad&aacute;te, nemus&iacute;te &scaron;abl&oacute;nu označovať ako prednastaven&uacute;. V pr&iacute;pade, že parameter nevypln&iacute;te, zobraz&iacute; sa &scaron;abl&oacute;na prednastaven&aacute;.';
$lang['helpbrowsecattemplate'] = 'Použitie &scaron;abl&oacute;ny z datab&aacute;zy pre zobrazenie zoznamu kateg&oacute;rii. T&aacute;to &scaron;abl&oacute;na mus&iacute; byť vytvoren&aacute; a mus&iacute; byť zobrazen&aacute; v z&aacute;ložke &Scaron;abl&oacute;ny pre zoznam kateg&oacute;rii. V pr&iacute;pade, že tento parameter zad&aacute;te, nemus&iacute;te &scaron;abl&oacute;nu označovať ako prednastaven&uacute;. V pr&iacute;pade, že parameter nevypln&iacute;te, zobraz&iacute; sa &scaron;abl&oacute;na prednastaven&aacute;.';
$lang['helpdetailtemplate'] = 'Použ&iacute;vať oddelen&uacute; &scaron;abl&oacute;nu pre detail.  T&aacute;to &scaron;abl&oacute;na m&aacute; b&yacute;ť v  modules/News/templates.';
$lang['helpsortby'] = 'Pole pre triedenie. Možnosti s&uacute;: &quot;news_date&quot;, &quot;summary&quot;, &quot;news_data&quot;, &quot;news_category&quot;, &quot;news_title&quot;.  Predvolen&eacute; je &quot;news_date&quot;.';
$lang['helpsortasc'] = 'Triediť novinky vzostupne.';
$lang['helpdetailpage'] = 'Str&aacute;nka, kde s&aacute; bude zobrazovať detail novinky M&ocirc;že byť ako ID str&aacute;nky alebo alias str&aacute;nky. Použ&iacute;va sa v pr&iacute;pade, keď chcete detail zobraziť v inej &scaron;abl&oacute;ne ako m&aacute;te zobrazen&yacute; s&uacute;hrn.';
$lang['helpshowarchive'] = 'Uk&aacute;ž star&eacute; pr&iacute;spevky.';
$lang['helpbrowsecat'] = 'Uk&aacute;že prech&aacute;dzateľn&yacute; zoznam kateg&oacute;ri&iacute;.';
$lang['helpaction'] = 'Nastavenie prednastavenej akcie. Možn&eacute; hodnoty s&uacute; &#039;default&#039; pre v&yacute;pis a detail novinky a &#039;fesubmit&#039; pre zobrazenie formul&aacute;ra na odoslanie novinky n&aacute;v&scaron;tevn&iacute;kom webu.';
$lang['help'] = '<h3>D&ocirc;ležit&eacute; upozornenie</h3>
<p>Od verzie 2.9 a vy&scaron;&scaron;ej bol z modulu odstr&aacute;nen&yacute; prednastaven&yacute; form&aacute;t d&aacute;tumu a zobrazenie d&aacute;tumu formatpostdate. Namiesto entry->formatpostdate m&ocirc;žete použ&iacute;ť  entry->post_date, alebo  entry->cms_date_format, ktor&yacute; nadefinovan&yacute; v glob&aacute;lnej konfigur&aacute;cii.</p>	
<h3>Čo rob&iacute; tento modul?</h3>
	<p>Novinky s&uacute; modul pre zobrazovanie udalost&iacute; na Va&scaron;ich str&aacute;nkach, podobne ako blogov&eacute; z&aacute;pisy, iba s viacej možnosťami! Po in&scaron;tal&aacute;cii modulu je vložen&aacute; daľ&scaron;ia položka do administračn&eacute;ho menu a to V&aacute;m umožn&iacute; vybrať alebo vložiť kateg&oacute;riu noviniek. Po vytvoren&iacute; alebo v&yacute;bere kateg&oacute;rie je zobrazen&yacute; zoznam noviniek pre t&uacute;to kateg&oacute;riu. Odtiaľto m&ocirc;žete prid&aacute;vať, upravovať alebo mazať novinky konkr&eacute;tnej kateg&oacute;rie.</p>
	<h3>Bezpečnosť</h3>
	<p>Aby už&iacute;vateľ m&ocirc;hol prid&aacute;vať, upravovať alebo mazať novinky, mus&iacute; mať opr&aacute;vnenia skupiny &#039;Modify News&#039;.</p>
	<h3>Ako sa použ&iacute;va?</h3>
	<p>Nejednoduch&scaron;ie použitie je vo využit&iacute; t&aacute;gu cms_module. Toto vlož&iacute; modul do &scaron;abl&oacute;ny alebo str&aacute;nky a zobraz&iacute; novinky ako si prajete. Samotn&yacute; k&oacute;d bude vyzerať podobne: <code>{cms_module module=&quot;news&quot; number=&quot;5&quot; category=&quot;beer&quot;}</code></p>

<h4>Možnosti zobrazenia</h4>
<h4>Numerous display methods</h4>
<p>The parameters supported by the news module, and support for numerous templates of each time mean that your options for displaying news articles are limitless.</p>
<h4>Custom Fields</h4>
<p>The News module allows defining numerous custom fields (including files and images) that will allow you to attach pdf files or numerous images to your articles.</p>
        <h4>Categories</h4>
	<p>News supplies a hierarchical category mechanism for organizing your articles.  A news article can only be in one place in the hierarchy.</p>
        <h4>RSS Feeds</h4>
        <p>News supports generating simple rss feeds from your news articles, so that your visitors can always be up to date with what is happening on your site.</p>
	<h4>Expiry and Status</h4>
	<p>Each news article can have an optional expiry date, after which it will not be shown on your web page.  As well, articles can be marked as <em>draft</em> to remove them permanently from your web page.</p>
	<h3>Security</h3>
	<p>The user must belong to a group with the &#039;Modify News&#039; permission in order to add or edit News entries.</p>
        <p>As well, In order to delete news entries, the user must belong to a group with the &#039;Delete News Articles&#039; permission.</p>
	<p>In order to edit the layout templates, the user must belong to a group with the &#039;Modify Templates&#039; permission.</p>
	<p>In order to edit the global news preferences, the user must belong to a group with the &#039;Modify Site Preferences&#039; permission.</p>
	<p>Additionally, to approve news for frontend display the user must belong to a group with the &#039;Approve News&#039; permission.</p>
	<h3>How do I use it?</h3>
	<p>The easiest way to use it is with the {news} wrapper tag (wraps the module in a tag, to simplify the syntax).  This will insert the module into your template or page anywhere you wish, and display news items.  The code would look something like: <code>{news number=&#039;5&#039;}</code></p>
<h3>Templates</h3>
<p>Since version 2.3 News supports multiple database templates, and no longer supports additional file templates.  Users who used the old file template system should follow these steps (for each file template):</p>
<ul>
<li>Copy the file template into the clipboard</li>
<li>Create a new database template <em>(either summary or detailed as required)</em>.  Give the new template the same name (including the .tpl extension) as the old file template, and paste the contents.</li>
<li>Hit Submit</li>
</ul>
<p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
$lang['qca'] = 'P0-1608926040-1271144175783';
$lang['utma'] = '156861353.786385904.1271157997.1279783450.1279798608.56';
$lang['utmz'] = '156861353.1279639848.54.48.utmcsr=geekmoot.com|utmccn=(referral)|utmcmd=referral|utmcct=/2010/news/7/15/Call-for-Papers/';
$lang['chartbeat2'] = '87v0u4nbwegh3lki';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>